@@ -45,22 +45,6 @@ static readdr *readdr_list = NULL;	/* list of re-addresses */
 
 /* ---- local functions ---- */
 
-void s_in_assign(struct sockaddr_in * src, 
-#if defined(__386BSD__) || defined(__bsdi__)
-  struct osockaddr_in * dst)
-#else
-  struct sockaddr_in * dst)
-#endif
-  {
-   memcpy(dst, src, sizeof(struct sockaddr_in));
-
-   /* fix up the fields that are swapped around in 386bsd		*/
-   #if defined(__386BSD__) || defined(__bsdi__)
-     dst->sin_family = src->sin_family;
-     dst->sin_len = 0;
-   #endif
-  }
-
 /* Create a datagram socket.
  */
 static int
@@ -228,11 +212,7 @@ place_my_address(sock, addr)
 	}
     if(r == NULL)
 	IN_ADDR(*sock) = me->host_addr;
-    #if defined(__386BSD__) || defined(__bsdi__)
-      sock->sin_family = AF_INET;
-    #else
-      sock->sin_family = htons(AF_INET);
-    #endif
+    sock->sin_family = htons(AF_INET);
 }
 
 /* sendit() sends the completed message to the talk daemon at the given
@@ -422,21 +402,16 @@ find_daemon(addr)
 
     m1 = omsg;
     m2 = nmsg;
-    s_in_assign(&talkd[otalk].sock, &m1.ctl_addr);
+    m1.ctl_addr = talkd[otalk].sock;
     place_my_address(&(m1.ctl_addr), addr);
-    s_in_assign(&talkd[ntalk].sock, &m2.ctl_addr);
+    m2.ctl_addr = talkd[ntalk].sock;
     place_my_address(&(m2.ctl_addr), addr);
     m1.type = m2.type = LOOK_UP;
     m1.id_num = m2.id_num = htonl(0);
     m1.r_tty[0] = m2.r_tty[0] = '\0';
     strcpy(m1.r_name, "ytalk");
     strcpy(m2.r_name, "ytalk");
-    m1.addr.sin_family = m2.addr.sin_family = 
-    #if defined(__386BSD__) || defined(__bsdi__)
-      AF_INET;
-    #else
-      htons(AF_INET);
-    #endif
+    m1.addr.sin_family = m2.addr.sin_family = htons(AF_INET);
 
     out = 0;
     for(i = 0; i < 5; i++)
@@ -524,8 +499,8 @@ init_socket()
 
     strncpy(nmsg.l_name, me->user_name, NAME_SIZE);
 
-    s_in_assign(&talkd[otalk].sock, &omsg.ctl_addr);
-    s_in_assign(&talkd[ntalk].sock, &nmsg.ctl_addr);
+    omsg.ctl_addr = talkd[otalk].sock;
+    nmsg.ctl_addr = talkd[ntalk].sock;
     nmsg.vers = TALK_VERSION;
 
     (void)find_daemon(me->host_addr);
@@ -675,16 +650,14 @@ send_dgram(user, type)
 	strncpy(nmsg.r_name, user->user_name, NAME_SIZE);
 	strncpy(nmsg.r_tty, user->tty_name, TTY_SIZE);
     }
-    s_in_assign(&user->sock, &nmsg.addr);
-    nmsg.addr.sin_family = 
-    #if defined(__386BSD__) || defined(__bsdi__)
-      AF_INET;
-    #else
-      htons(AF_INET);
-    #endif
-
+    nmsg.addr = user->sock;
+    nmsg.addr.sin_family = htons(AF_INET);
     if(sendit(addr, d) != 0)
+    {
+	if(type == AUTO_LOOK_UP || type == AUTO_DELETE)
+	    strncpy(nmsg.l_name, me->user_name, NAME_SIZE);
 	return -2;
+    }
 
     switch(type)
     {
@@ -719,13 +692,8 @@ send_auto(type)
     nmsg.type = type;
     strcpy(nmsg.r_name, "+AUTO");
     nmsg.r_tty[0] = '\0';
-    s_in_assign(&autosock, &nmsg.addr);
-    nmsg.addr.sin_family = 
-    #if defined(__386BSD__) || defined(__bsdi__)
-      AF_INET;
-    #else
-      htons(AF_INET);
-    #endif
+    nmsg.addr = autosock;
+    nmsg.addr.sin_family = htons(AF_INET);
 
     rc = 0;
     dtype = find_daemon(me->host_addr);
@@ -866,11 +834,12 @@ get_host_addr(hostname)
     ylong addr;
     ylong inet_addr();
 
+    errno = 0;
     if((host = (struct hostent *) gethostbyname(hostname)) != NULL)
     {
 	if(host->h_length != sizeof(addr))
 	{
-	    sprintf(errstr, "Bad IN addr: %s\n", hostname);
+	    sprintf(errstr, "Bad IN addr: %s", hostname);
 	    show_error(errstr);
 	    return (ylong)-1;
 	}
@@ -914,19 +883,19 @@ readdress_host(from_id, to_id, on_id)
 
     if((from_addr = get_host_addr(from_id)) == (ylong)-1)
     {
-	sprintf(errstr, "Unknown host: '%s'\n", from_id);
+	sprintf(errstr, "Unknown host: '%s'", from_id);
 	show_error(errstr);
 	return;
     }
     if((to_addr = get_host_addr(to_id)) == (ylong)-1)
     {
-	sprintf(errstr, "Unknown host: '%s'\n", to_id);
+	sprintf(errstr, "Unknown host: '%s'", to_id);
 	show_error(errstr);
 	return;
     }
     if((on_addr = get_host_addr(on_id)) == (ylong)-1)
     {
-	sprintf(errstr, "Unknown host: '%s'\n", on_id);
+	sprintf(errstr, "Unknown host: '%s'", on_id);
 	show_error(errstr);
 	return;
     }
